@@ -4,3 +4,7 @@ def create_thumbnail(file_path, format):
 
 def should_create_thumbnail(file_path):
     return False
+
+
+def image_verify(f):
+    return
